@@ -21,8 +21,9 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 THE SOFTWARE.
 */
 
-#ifndef SRC_LIBPIANO_PIANO_H_MFBT13PN
-#define SRC_LIBPIANO_PIANO_H_MFBT13PN
+#pragma once
+
+#include "../config.h"
 
 #include <stdbool.h>
 #ifdef __FreeBSD__
@@ -64,7 +65,8 @@ typedef struct PianoStation {
 typedef enum {
 	PIANO_RATE_NONE = 0,
 	PIANO_RATE_LOVE = 1,
-	PIANO_RATE_BAN = 2
+	PIANO_RATE_BAN = 2,
+	PIANO_RATE_TIRED = 3,
 } PianoSongRating_t;
 
 /* UNKNOWN should be 0, because memset sets audio format to 0 */
@@ -148,6 +150,18 @@ typedef struct {
 	PianoSong_t *feedback;
 } PianoStationInfo_t;
 
+typedef struct {
+	char *username;
+	bool explicitContentFilter;
+} PianoSettings_t;
+
+typedef struct {
+	PianoListHead_t head;
+	char *name, *description;
+	bool isAlgorithmic, isTakeover, active;
+	int id;
+} PianoStationMode_t;
+
 typedef enum {
 	/* 0 is reserved: memset (x, 0, sizeof (x)) */
 	PIANO_REQUEST_LOGIN = 1,
@@ -170,6 +184,10 @@ typedef enum {
 	PIANO_REQUEST_GET_STATION_INFO = 20,
 	PIANO_REQUEST_DELETE_FEEDBACK = 21,
 	PIANO_REQUEST_DELETE_SEED = 22,
+	PIANO_REQUEST_GET_SETTINGS = 23,
+	PIANO_REQUEST_CHANGE_SETTINGS = 24,
+	PIANO_REQUEST_GET_STATION_MODES = 25,
+	PIANO_REQUEST_SET_STATION_MODE = 26,
 } PianoRequestType_t;
 
 typedef struct PianoRequest {
@@ -245,6 +263,28 @@ typedef struct {
 	PianoStation_t *station;
 } PianoRequestDataDeleteSeed_t;
 
+typedef enum {
+	PIANO_UNDEFINED = 0,
+	PIANO_FALSE = 1,
+	PIANO_TRUE = 2,
+} PianoTristate_t;
+
+typedef struct {
+	char *currentUsername, *newUsername;
+	char *currentPassword, *newPassword;
+	PianoTristate_t explicitContentFilter;
+} PianoRequestDataChangeSettings_t;
+
+typedef struct {
+	PianoStation_t *station;
+	PianoStationMode_t *retModes;
+} PianoRequestDataGetStationModes_t;
+
+typedef struct {
+	PianoStation_t *station;
+	unsigned int id;
+} PianoRequestDataSetStationMode_t;
+
 /* pandora error code offset */
 #define PIANO_RET_OFFSET 1024
 typedef enum {
@@ -334,6 +374,7 @@ void PianoDestroy (PianoHandle_t *);
 void PianoDestroyPlaylist (PianoSong_t *);
 void PianoDestroySearchResult (PianoSearchResult_t *);
 void PianoDestroyStationInfo (PianoStationInfo_t *);
+void PianoDestroyStationMode (PianoStationMode_t * const);
 
 /* pandora rpc */
 PianoReturn_t PianoRequest (PianoHandle_t *, PianoRequest_t *,
@@ -346,4 +387,3 @@ PianoStation_t *PianoFindStationById (PianoStation_t * const,
 		const char * const);
 const char *PianoErrorToStr (PianoReturn_t);
 
-#endif /* SRC_LIBPIANO_PIANO_H_MFBT13PN */
